pro get_ssc_best, indexin, iout, dataout, _extra=_extra, $
       maxdt=maxdt, actdt=actdt, filtb=filtb, half=half, quart=quart, $
       later_only=later_only, earlier_only=earlier_only, $
       status=status, expand_days=expand_days, recurse=recurse, $
       delta_sec=delta_sec, debug=debug
;
;+
;   Name: get_ssc_best
;
;   Purpose: return 'index,data' for "best" SSC matching 
;
;   Input Parameters:
;      indexin - index/time to match
;
;   Output Parameters:
;      iout, dataout - the corresponding SSC/SSS index,data pair
;
;   Keyword Parameters:
;      maxdt - maximum "acceptable" delta-time in hours
;      actdt - acutal delta-time from input time
;      filtb - optional filter b (integer 2: Al1, 3: AlMg)
;      res   - optional resolution (integer: 1: half, 2: quarter)
;      half  - switch, synonym for res=1
;      quarter - switch, synonym for res=2
;      expand_days - number of days to allow expanding search 
;      status - 1: match found/returned in iout,dataout
;               0: no match found with desired constraints
;
;   Calling Sequence:
;      IDL> get_ssc_best, timein, index, data [/half, /quart, filtb=xx]
;
;   History:
;      23-Jan-2001 - simplify some auto-context (ssw_fov_context) and SSC work
;
;-  

common get_ssc_best, recdays
;
;
debug=keyword_set(debug)
if n_elements(expand_days) eq 0 then expand_days=0
if n_elements(recurse) eq 0 then recdays=1 else recdays=recdays+1
status=0
if n_elements(maxdt) eq 0 then maxdt=24       ; hours
case 1 of
   keyword_set(later_only): window=[0,maxdt] +   (recdays*[0,24])
   keyword_set(earlier_only): window=[-(maxdt),0] + (recdays*[-24,0])
   else: window=replicate(maxdt(0),2)*[-1,1] +     (recdays*[-24,24])
endcase

time_window, indexin(0), t0, t1, hours=window
ssc=ssc_files(t0, t1, _extra=_extra)
if ssc(0) eq '' then begin 
   box_message,'No ssc files in desired window'
   if expand_days gt recdays then begin
      box_message,'expanding search window'
      get_ssc_best,indexin,iout, dataout, _extra=_extra, $
         filtb=filtb, half=half, quarter=quarter, /recurse, recdays=recdays, expand_days=expand_days 
   endif else begin
     box_message,' Giving up...'
     retall
   endelse
endif

rd_roadmap,ssc,rmap

case 1 of 
   keyword_set(filtb):fb=strtrim(filtb,2)
   else: fb='2,3'
endcase 
   
case 1 of 
   keyword_set(quarter): res='2'
   keyword_set(half):    res='1'
   else: res='1,2'
endcase

ss=struct_where(rmap,test=['gt_filtb='+fb, 'gt_res='+res],count,/quiet)
if count eq 0 then begin
   box_message,'No SSC images match your desired parameters...'
   return
endif

sss=tim2dset(rmap(ss),indexin(0), delta_sec=delta_sec)

actdt=delta_sec/3600.                 ; delta-hours between input/output

read_sxt, ssc, ss(sss(0)), iout, dataout
if debug then stop,'before return'
return
end
 

