pro sxt_sff_composite,index,data,comp_index,comp_data, $
	smooth_factor=smooth_factor, _extra=_extra,    $
        sxt_cleanx=sxt_cleanx, vignette=vignette, destreak=destreak, $
        fillpix=fillpix
;+
; NAME:
;   sxt_sff_composite
;
; PURPOSE:
;   Prepare a composite SXT image from 2 or 3 Half or Quarter Res images.
;
; CALLING SEQUENCE EXAMPLES:
;
; INPUTS:
;   index = SXT index structure
;   data  = 3-d data cube (at least 2 images)
;
;
; OUTPUT:
;   comp_index - the adjusted index of the composite (history added)
;   comp_data  - the composite data array
;
; OPTIONAL INPUT KEYWORDS:
;
;   smooth_factor = Boxcar smooth the bleed pixels.  If not defined, the
;	     default is to smooth over 5 pixels.
;   _extra - all others passed through to sxt_prep
;
; MODIFICATION HISTORY:
;   15-sep-98  S.L.Freeland - from LWA 'sxt_composite.pro'
;              stripped version using 'new technology'
;              Calls sxt_prep internally
;   21-Mar-99  S.L.Freeland - call sxt_clean independent from sxt_prep
;              add /destreak, update history 
;    7-Apr-99  S.L.Freeland - verify all indices->.HIS.time_compos/.day_compos
;   26-Oct-99  S.L.Freeland - enabled keyword inherit->sxt_prep
;   18-Dec-00  S.L.Freeland - merge LWA 'sxt_suture'
;
;    Previous History:
;    8-Nov-91, L. W. Acton (Wrote composite)
;   19-May-92, LWA  (Several more mods in betwee)
;   13-may-93, J. R. Lemen, Re-wrote.  Calls sxt_satpix
;    1-Dec-93, MDM - Corrected error with the use of "s2" (when it is -1)
;		- Modification on selection of replacement pixels.
;		  It used to check (a) that it was high signal (ge 90)
;				   (b) that it was not saturated
;		  Added check so that it replaced pixels in the longer 
;		  exposure only when the longer exposure was saturated
;    15-Dec-93, SLF - Fixed typo (stapix->satpix)
;    22-feb-94, JRL - Corrected the algorithm; 
;		    - added smooth_factor, sfd, dc_interpolate, register keywords
;    17-Apr-94, LWA - Fixed /sfd scaling option (1000.*  was needed)
;		    - Changed /plot to plot raw input images.
;		    - Added RESTRICTIONS statement to header.
;		    - Added despike=despike keyword.
;    23-jun-94, JRL - Output is floating if input is a fltarr;
;		    - Call sfd_comp with index=index to normalize properly
;    08-May-95, LWA - Fixed to return negative values.
;    02-Nov-96, LWA - Added output of index with history record.
;		    - Made dc_data a keyword intput.
;		    - Made dc_interpolate the default is dc_data not input.
;    04-Nov-96, LWA - Removed forgotten diagnostic.
;    10-Jan-97, LWA - Corrected calling sequence examples.
;-

progverno=4.20

destreak=keyword_set(destreak)
cleanit=keyword_set(sxt_cleanx) or destreak

nparams = n_params()
if nparams lt 4 then begin
   box_message,'IDL> sxt_sff_composite,index,data,compindex,compdata
   return
endif

;-------------------------
;  Check input parameters
;-------------------------

sz0 = size(data)			; Data must be 3-d
nimg=data_chk(data,/nimage)

if nimg lt 2 or n_elements(index) lt 2 then begin
   print,'***  Error in sxt_composite:  index,data must be 3-d'
   return
endif

exporder=sort(gt_expdur(index))

; ----- the folling call orders output short->long
sxt_prep,index(exporder),data(*,*,exporder),comp_index,img,unc,satp, $
  /register,/float,/dc_orbit_correct,ref_image=index(exporder(nimg-1)), $
  vignette=vignette, _extra=_extra               ; sxt_clean=sxt_clean

t0 = gt_expdur(comp_index)

uncert=sxt_dn_unc(comp_index,img,te=alog10(2.3e6),/float,unc)

xsize = data_chk(comp_data,/nx)
ysize = data_chk(comp_data,/ny)

; ---------------------------------------------------------------------------
; Composite Algorithm
   ii00 = where(satp(*,*,1) eq 1,nii00)
   cimgA = img(*,*,1)
   if nii00 gt 0 then begin
      if NOT keyword_set(nofill) then begin
         fill_imgA = sxt_suture(img(*,*,1),satp(*,*,1),uncert(*,*,1),$
                unc_out=uncert_outA)
         cimgA(ii00) = fill_imgA(ii00)
      endif else begin
         cimgA(ii00) = (img(*,*,0))(ii00)*t0(1)/t0(0)
      endelse
   endif
   cimg = cimgA

   if nimg eq 3 then begin
      ii10 = where(satp(*,*,2) eq 1,nii10)
      cimgB = img(*,*,2)
      if nii10 gt 0 then begin
         if NOT keyword_set(nofill) then begin
            fill_imgB = sxt_suture(img(*,*,2),satp(*,*,2),uncert(*,*,2),$
                unc_out=uncert_outB)
            cimgB(ii10) = fill_imgB(ii10)
         endif else begin
            cimgB(ii10) = cimgA(ii10)*t0(2)/t0(1)
         endelse
      endif
      cimg = cimgB
   endif else nii10 = 0

comp_data=temporary(cimg)               ; return data (composite image)
cindex=comp_index                       ; all indices 
comp_index=comp_index(nimg-1)		;Longest exposure.
fillpix=make_array(xsize,ysize,/byte)

if nii00 gt 0 then fillpix(nii00) =1
if nii10 gt 0 then fillpix(nii10) =2

his_index, /enable

; do clean/destreak after the fact
if cleanit then begin
   if n_elements(nsigma) eq 0 then nsigma=3
   comp_data=sxt_clean(comp_index, comp_data, nsigma=nsigma, xsaa=destreak)   
   his_index, comp_index, 0, 'extra1', nsigma
   his_index, comp_index, 0, 'q_extra', 4 + destreak ; 4=> clean (only)
endif

time_compos=gt_time(cindex)
day_compos =gt_day(cindex)

his_index, comp_index, 0, 'q_composite', progverno*1000
his_index, comp_index, 0, 'time_compos', time_compos
his_index, comp_index, 0, 'day_compos', day_compos

return
end

